==> peperit_2.0_estable.zip: themes/peperit/html_files/componentes/plantilla/plantilla_footer.php <==
<?php

/* 
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
 
 //Configuramos el contenido:
 $tieneBlog = false;
?>
<footer id="footer">
        <div class="footer-center">
            <div class="<?=Theme::getConfigParam('container_style', 'container');?>">
                <div class="row">
                    <div class="footer-static row-fluid">
                        <div class="footer-block footer_logo col-xs-12 col-sm-3 col-md-3">
                            <div class="logo_center">
                                <ul class="logo-bullet">
                                    <li>
                                        <em class="em1 hidden-sm hidden-xs">
                                            <i class="icon-map-markerr "></i>
                                        </em>
                                        <em class="em"><?= Shop::$empresa->direccion; ?> - <?= Shop::$empresa->localidad; ?> (<?= Shop::$empresa->cod_postal; ?>) <?= ((strtoupper(Shop::$empresa->localidad) != strtoupper(Shop::$empresa->provincia)) ? '-' . Shop::$empresa->provincia : ''); ?></em>
                                        
                                    </li>
                                    <li>
                                        <em class="em1 hidden-sm hidden-xs">
                                            <i class="icon-phonee "></i>
                                        </em>
                                        <em>+34 <?= Shop::$empresa->telefono_empresa ?></em>
                                    </li>
                                    <li>
                                        <em class="em1 hidden-sm hidden-xs">
                                            <i class="icon-email"></i>
                                        </em>
                                        <em>
                                            <a href="mailto:<?= Shop::$empresa->email_empresa ?>" title=""><?= Shop::$empresa->email_empresa ?></a>
                                        </em>
                                    </li>
                                </ul>
                            </div>
                        </div>
                        <div class="footer-block footer_logo hidden-sm hidden-xs col-md-3">
<?php
	new Widget($_WH->GW('banner'), 'banner_logo_pie', 'logo_pie', 1, true);
?>
                        </div>
                        <div class="footer-block col-xs-12 col-sm-3 col-md-2">
                            <h4 class="title_font">
                                <?=traducir('Destacamos');?>
                            </h4>
                            <ul class="toggle-footer bullet" style="">
                                <li>
                                    <a href="<?=Shop::$configuracion->url;?>">
                                        <?=traducir('Novedades');?>
                                    </a>
                                </li>
<?php
	if ($tieneBlog){
?>
                                <li>
                                    <a href="<?=Shop::$configuracion->url;?>blog/events">
                                        <?=traducir('Próximos eventos');?>
                                    </a>
                                </li>
<?php
	}
?>
                                <li>
                                    <a href="<?=Shop::$configuracion->url;?>contacto">
                                        <?=traducir('Contacto');?>
                                    </a>
                                </li>
                                <li>
                                    <a href="<?=Shop::$configuracion->url;?>conocenos">
                                        <?=traducir('Quienes somos');?>
                                    </a>
                                </li>
                            </ul>
                        </div>
                        <section class="footer-block col-xs-12 col-sm-3 col-md-2">
                            <h4>
                                <a href="javascript:void(0);" title="Administrar mi cuenta de cliente" rel="nofollow">
                                    <?=traducir('Mi cuenta');?>
                                </a>
                            </h4>
                            <div class="block_content toggle-footer" style="">
                                <ul class="bullet">
                            <?php
                                if(Usuario:: isLogged()){
                            ?>
                                    <li>
                                        <a href="<?=Shop::$configuracion->url;?>mis_datos" title="Mi cuenta" rel="nofollow">
                                            <?=traducir('Mi cuenta');?>
                                        </a>
                                    </li>
                                    <li>
                                        <a href="<?=Shop::$configuracion->url;?>direcciones_envio" title="Mis direcciones" rel="nofollow">
                                            <?=traducir('Mis direcciones');?>
                                        </a>
                                    </li>
                                    <li>
                                    <a href="<?=Shop::$configuracion->url;?>historico_pedidos" title="Mis pedidos" rel="nofollow">
                                        <?=traducir('Mis pedidos');?>
                                    </a>
                                    </li>
                            <?php
                            }else{
                            ?>
                                    <li>
                                        <a href="<?=Shop::$configuracion->url;?>registro" title="Administrar mi información personal" rel="nofollow">
                                            <?=traducir('Registro');?>
                                        </a>
                                    </li>
                                    <li>
                                        <a class="link-login" href="<?=Shop::$configuracion->url;?>acceso" title="Iniciar sesión" rel="nofollow">
                                            <?=traducir('Iniciar sesión');?>
                                        </a>
                                    </li>
                            <?php
                            }
                            ?>
                                </ul>
                            </div>
                        </section>
                        <section class="footer-block col-xs-12 col-sm-3 col-md-2" id="block_various_links_footer">
                            <h4>
                                <?=traducir('Información');?>
                            </h4>
                            <ul class="toggle-footer bullet" style="">
                                <li class="item">
                                    <a href="<?= Shop::$configuracion->url ?>aviso_legal" title="<?= traducir('Aviso legal') ?>">
                                        <?= traducir('Aviso legal') ?>
                                    </a>
                                </li>
                                <li class="item">
                                    <a href="<?= Shop::$configuracion->url ?>privacidad" title="<?= traducir('Política de privacidad') ?>">
                                        <?= traducir('Política de privacidad') ?>
                                    </a>
                                </li>
                                
                                <li class="item">
                                    <a href="<?= Shop::$configuracion->url ?>condiciones_venta" title="<?= traducir('Entregas y devoluciones') ?>">
                                        <?= traducir('Entregas y devoluciones') ?>
                                    </a>
                                </li>
                                <li class="item">
                                    <a href="<?= Shop::$configuracion->url ?>cookies" title="<?= traducir('Política de Cookies'); ?>">
                                        <?= traducir('Cookies'); ?>
                                    </a>
                                </li>
                            </ul>
                        </section>
                        
                    </div>
                </div>
            </div>
        </div>
     <?php
//Ahora cargamos el banner múltiple
$ruta_cabecera = Theme::include_file("subencion.php");
?>
        <!-- otra cosa -->
        <div class="footer-bottom">
            <div class="<?=Theme::getConfigParam('container_style', 'container');?>">
                <div class="row">
                    <div class="footer-static row-fluid">
                        <div class="footer-address col-xs-12 col-sm-6 col-md-6">
                            <p>
                                © 2019. <?= Shop::$empresa->nombre ?>. <?=traducir('Desarrollado por');?> <a href="http://www.arminet.es/">Arminet Software&AMP;web</a>
                            </p>
                        </div>
                        <div id="social_block" class="col-xs-12 col-sm-6 col-md-6">
                            <ul>
                               <?php 
                               new Widget($_WH->GW("redes_sociales","redes_sociales"), new OpcionesWidget(array("ficheroRedSocial" => "itemSocialMediaFooter")));
                               ?>
                                
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
<?php
//Esto es un ejemplo de como funciona el login de google
/*
		<div class="g-signin2" data-onsuccess="onSignIn"></div>
		<a href="#" onclick="signOut();">Sign out</a>
		<script>
		function onSignIn(googleUser) {
			var profile = googleUser.getBasicProfile();
			console.log('ID: ' + profile.getId()); // Do not send to your backend! Use an ID token instead.
			console.log('Name: ' + profile.getName());
			console.log('Image URL: ' + profile.getImageUrl());
			console.log('Email: ' + profile.getEmail()); // This is null if the 'email' scope is not present.
		}
		  function signOut() {
			var auth2 = gapi.auth2.getAuthInstance();
			auth2.signOut().then(function () {
			  console.log('User signed out.');
			});
		  }
		</script>
*/
?>
<?php
    $newsletter = Module::Newsletter_basic();
    echo($newsletter);
?>
    </footer>
<script>

document.addEventListener('WSLE', function(event) {
    $(document).ready(function () {
        
        //Marina(03/Enero/2020) si el ancho de la pantalla es mayor que 600 ejecutamos el jquery
        //esto resuelve el problema de estilos que existia en moviles
        var ventana_ancho = $(window).width();

        if(ventana_ancho >= 600){

    		activarSticky();
            //Vamos a controlar el sticky menu:
            //sticky-fixed-top
            //$(document).on('scroll', function () {
            document.addEventListener('scroll', function(){
                activarSticky();
            }, {passive: true});
            function activarSticky() {
                //Vamos a ver si la barra se ve entera:
                if ($("#contenedorNav").visible()) {
                    barraCabecera = $("#contenedorNav").find('nav.main-navigation');
                    if (barraCabecera.hasClass('fixed')) {
                        barraCabecera.removeClass('fixed');
                        $('#sticky_top.sticky-fixed-top').removeClass('sticky-fixed-top');
                        $('#contenedorNav').removeClass('fieldmegamenu-sticky');
                        $("#sticky_top").css('right', 'auto');
                    }

                } else {
                    barraCabecera = $("nav.main-navigation");
                    totalElementos = barraCabecera.length;
                    if (totalElementos > 0) {
                        if (!barraCabecera.hasClass('fixed')) {
                            barraCabecera.addClass('fixed');
                            $('#sticky_top').addClass('sticky-fixed-top');
                            $('#contenedorNav').addClass('fieldmegamenu-sticky');
							//Pedro 13/Mayo/2020 ==> quitamos esta opción porque se me pone encima de la cesta,lo dejamos como auto
                            //$("#sticky_top").css('right', ( $('body').width() - $('nav .container').outerWidth() ) / 2 + "px");
							 $("#sticky_top").css('right', 'auto');
                        }
                    }
                }
            }
        }
        $('.v-megamenu.dropdown-menu').on("click", function (event) {
            event.stopPropagation();
        });
		
		 /* ===========================================================================

        SCRIPT >>> ALTURA MENU AL HACER SCROLL

        ============================================================================ */

            //$(document).on("scroll",function(){
            document.addEventListener('scroll', function(){
            if($(document).scrollTop()>100){
                //$("header").removeClass("large_header").addClass("small_header");
                $("header nav div.large_topBar").removeClass("large_topBar").addClass("small_topBar");
                $("header nav a.navbar-brand").removeClass("large_logo").addClass("small_logo");
                $("header div.busquedaCesta").removeClass("large_cesta").addClass("small_cesta");
            } else{
                //$("header").removeClass("small_header").addClass("large_header");
                $("header nav div.small_topBar").removeClass("small_topBar").addClass("large_topBar");
                $("header nav a.navbar-brand").removeClass("small_logo").addClass("large_logo");
                $("header div.busquedaCesta").removeClass("small_cesta").addClass("large_cesta");
            }
        }, {passive: true});
    });
});
</script>

==> peperit_2.1.01_estable.zip: themes/peperit/html_files/componentes/plantilla/plantilla_footer.php <==
<?php

/* 
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
 
 //Configuramos el contenido:
 $tieneBlog = false;
?>
<footer id="footer">
        <div class="footer-center">
            <div class="<?=Theme::getConfigParam('container_style', 'container');?>">
                <div class="row">
                    <div class="footer-static row-fluid">
                        <div class="footer-block footer_logo col-xs-12 col-sm-3 col-md-3">
                            <div class="logo_center">
                                <ul class="logo-bullet">
                                    <li>
                                        <em class="em1 hidden-sm hidden-xs">
                                            <i class="icon-map-markerr "></i>
                                        </em>
                                        <em class="em"><?= Shop::$empresa->direccion; ?> - <?= Shop::$empresa->localidad; ?> (<?= Shop::$empresa->cod_postal; ?>) <?= ((strtoupper(Shop::$empresa->localidad) != strtoupper(Shop::$empresa->provincia)) ? '-' . Shop::$empresa->provincia : ''); ?></em>
                                        
                                    </li>
                                    <li>
                                        <em class="em1 hidden-sm hidden-xs">
                                            <i class="icon-phonee "></i>
                                        </em>
                                        <em>+34 <?= Shop::$empresa->telefono_empresa ?></em>
                                    </li>
                                    <li>
                                        <em class="em1 hidden-sm hidden-xs">
                                            <i class="icon-email"></i>
                                        </em>
                                        <em>
                                            <a href="mailto:<?= Shop::$empresa->email_empresa ?>" title=""><?= Shop::$empresa->email_empresa ?></a>
                                        </em>
                                    </li>
                                </ul>
                            </div>
                        </div>
                        <div class="footer-block footer_logo hidden-sm hidden-xs col-md-3">
<?php
	new Widget($_WH->GW('banner'), 'banner_logo_pie', 'logo_pie', 1, true);
?>
                        </div>
                        <div class="footer-block col-xs-12 col-sm-3 col-md-2">
                            <h4 class="title_font">
                                <?=traducir('Destacamos');?>
                            </h4>
                            <ul class="toggle-footer bullet" style="">
                                <li>
                                    <a href="<?=Shop::$configuracion->url;?>">
                                        <?=traducir('Novedades');?>
                                    </a>
                                </li>
<?php
	if ($tieneBlog){
?>
                                <li>
                                    <a href="<?=Shop::$configuracion->url;?>blog/events">
                                        <?=traducir('Próximos eventos');?>
                                    </a>
                                </li>
<?php
	}
?>
                                <li>
                                    <a href="<?=Shop::$configuracion->url;?>contacto">
                                        <?=traducir('Contacto');?>
                                    </a>
                                </li>
                                <li>
                                    <a href="<?=Shop::$configuracion->url;?>conocenos">
                                        <?=traducir('Quienes somos');?>
                                    </a>
                                </li>
                            </ul>
                        </div>
                        <section class="footer-block col-xs-12 col-sm-3 col-md-2">
                            <h4>
                                <?php
                                //Marina(24/07/2020) añado una condición: si no estas logueado no muestra ningun enlace
                                    if(Usuario:: isLogged()){
                                        ?>
                                        <a href="javascript:void(0);" title="Administrar mi cuenta de cliente" rel="nofollow">
                                            <?=traducir('Mi cuenta');?>
                                        </a>
                                        <?php
                                    }else{
                                        ?>
                                        <span><?=traducir('Mi cuenta');?></span>
                                        <?php
                                    }
                                ?>
                            </h4>
                            <div class="block_content toggle-footer" style="">
                                <ul class="bullet">
                            <?php
                                if(Usuario:: isLogged()){
                            ?>
                                    <li>
                                        <a href="<?=Shop::$configuracion->url;?>mis_datos" title="Mi cuenta" rel="nofollow">
                                            <?=traducir('Mi cuenta');?>
                                        </a>
                                    </li>
                                    <li>
                                        <a href="<?=Shop::$configuracion->url;?>direcciones_envio" title="Mis direcciones" rel="nofollow">
                                            <?=traducir('Mis direcciones');?>
                                        </a>
                                    </li>
                                    <li>
                                    <a href="<?=Shop::$configuracion->url;?>historico_pedidos" title="Mis pedidos" rel="nofollow">
                                        <?=traducir('Mis pedidos');?>
                                    </a>
                                    </li>
                            <?php
                            }else{
                            ?>
                                    <li>
                                        <a href="<?=Shop::$configuracion->url;?>registro" title="Administrar mi información personal" rel="nofollow">
                                            <?=traducir('Registro');?>
                                        </a>
                                    </li>
                                    <li>
                                        <a class="link-login" href="<?=Shop::$configuracion->url;?>acceso" title="Iniciar sesión" rel="nofollow">
                                            <?=traducir('Iniciar sesión');?>
                                        </a>
                                    </li>
                            <?php
                            }
                            ?>
                                </ul>
                            </div>
                        </section>
                        <section class="footer-block col-xs-12 col-sm-3 col-md-2" id="block_various_links_footer">
                            <h4>
                                <?=traducir('Información');?>
                            </h4>
                            <ul class="toggle-footer bullet" style="">
                                <li class="item">
                                    <a href="<?= Shop::$configuracion->url ?>aviso_legal" title="<?= traducir('Aviso legal') ?>">
                                        <?= traducir('Aviso legal') ?>
                                    </a>
                                </li>
                                <li class="item">
                                    <a href="<?= Shop::$configuracion->url ?>privacidad" title="<?= traducir('Política de privacidad') ?>">
                                        <?= traducir('Política de privacidad') ?>
                                    </a>
                                </li>
                                
                                <li class="item">
                                    <a href="<?= Shop::$configuracion->url ?>condiciones_venta" title="<?= traducir('Entregas y devoluciones') ?>">
                                        <?= traducir('Entregas y devoluciones') ?>
                                    </a>
                                </li>
                                <li class="item">
                                    <a href="<?= Shop::$configuracion->url ?>cookies" title="<?= traducir('Política de Cookies'); ?>">
                                        <?= traducir('Cookies'); ?>
                                    </a>
                                </li>
                            </ul>
                        </section>
                        
                    </div>
                </div>
            </div>
        </div>
     <?php
//Ahora cargamos el banner múltiple
$ruta_cabecera = Theme::include_file("subencion.php");
?>
        <!-- otra cosa -->
        <div class="footer-bottom">
            <div class="<?=Theme::getConfigParam('container_style', 'container');?>">
                <div class="row">
                    <div class="footer-static row-fluid">
                        <div class="footer-address col-xs-12 col-sm-6 col-md-6">
                            <p>
                                © 2020. <?= Shop::$empresa->nombre ?>. <?=traducir('Desarrollado por');?> <a href="http://www.arminet.es/">Arminet Software&AMP;web</a>
                            </p>
                        </div>
                        <div id="social_block" class="col-xs-12 col-sm-6 col-md-6">
                            <ul>
                               <?php 
                               new Widget($_WH->GW("redes_sociales","redes_sociales"), new OpcionesWidget(array("ficheroRedSocial" => "itemSocialMediaFooter")));
                               ?>
                                
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
<?php
//Esto es un ejemplo de como funciona el login de google
/*
		<div class="g-signin2" data-onsuccess="onSignIn"></div>
		<a href="#" onclick="signOut();">Sign out</a>
		<script>
		function onSignIn(googleUser) {
			var profile = googleUser.getBasicProfile();
			console.log('ID: ' + profile.getId()); // Do not send to your backend! Use an ID token instead.
			console.log('Name: ' + profile.getName());
			console.log('Image URL: ' + profile.getImageUrl());
			console.log('Email: ' + profile.getEmail()); // This is null if the 'email' scope is not present.
		}
		  function signOut() {
			var auth2 = gapi.auth2.getAuthInstance();
			auth2.signOut().then(function () {
			  console.log('User signed out.');
			});
		  }
		</script>
*/
?>
<?php
    $newsletter = Module::Newsletter_basic();
    echo($newsletter);
?>
    </footer>
<script>

document.addEventListener('WSLE', function(event) {
    $(document).ready(function () {
        
        //Marina(03/Enero/2020) si el ancho de la pantalla es mayor que 600 ejecutamos el jquery
        //esto resuelve el problema de estilos que existia en moviles
        var ventana_ancho = $(window).width();

        if(ventana_ancho >= 600){

    		activarSticky();
            //Vamos a controlar el sticky menu:
            //sticky-fixed-top
            //$(document).on('scroll', function () {
            document.addEventListener('scroll', function(){
                activarSticky();
            }, {passive: true});
            function activarSticky() {
                //Vamos a ver si la barra se ve entera:
                if ($("#contenedorNav").visible()) {
                    barraCabecera = $("#contenedorNav").find('nav.main-navigation');
                    if (barraCabecera.hasClass('fixed')) {
                        barraCabecera.removeClass('fixed');
                        $('#sticky_top.sticky-fixed-top').removeClass('sticky-fixed-top');
                        $('#contenedorNav').removeClass('fieldmegamenu-sticky');
                        $("#sticky_top").css('right', 'auto');
                    }

                } else {
                    barraCabecera = $("nav.main-navigation");
                    totalElementos = barraCabecera.length;
                    if (totalElementos > 0) {
                        if (!barraCabecera.hasClass('fixed')) {
                            barraCabecera.addClass('fixed');
                            $('#sticky_top').addClass('sticky-fixed-top');
                            $('#contenedorNav').addClass('fieldmegamenu-sticky');
							//Pedro 13/Mayo/2020 ==> quitamos esta opción porque se me pone encima de la cesta,lo dejamos como auto
                            //$("#sticky_top").css('right', ( $('body').width() - $('nav .container').outerWidth() ) / 2 + "px");
							 $("#sticky_top").css('right', 'auto');
                        }
                    }
                }
            }
        }
        $('.v-megamenu.dropdown-menu').on("click", function (event) {
            event.stopPropagation();
        });
		
		 /* ===========================================================================

        SCRIPT >>> ALTURA MENU AL HACER SCROLL

        ============================================================================ */

            //$(document).on("scroll",function(){
            document.addEventListener('scroll', function(){
            if($(document).scrollTop()>100){
                //$("header").removeClass("large_header").addClass("small_header");
                $("header nav div.large_topBar").removeClass("large_topBar").addClass("small_topBar");
                $("header nav a.navbar-brand").removeClass("large_logo").addClass("small_logo");
                $("header div.busquedaCesta").removeClass("large_cesta").addClass("small_cesta");
            } else{
                //$("header").removeClass("small_header").addClass("large_header");
                $("header nav div.small_topBar").removeClass("small_topBar").addClass("large_topBar");
                $("header nav a.navbar-brand").removeClass("small_logo").addClass("large_logo");
                $("header div.busquedaCesta").removeClass("small_cesta").addClass("large_cesta");
            }
        }, {passive: true});
    });
});
</script>
